import { __exports as promise } from '../../../_virtual/promise.mjs';
import { __require as requireAjv } from '../node_modules/ajv/lib/ajv.mjs';
import { __require as requireError } from './error.mjs';
import { __require as requireLib } from '../../har-schema/lib/index.mjs';

var hasRequiredPromise;

function requirePromise () {
	if (hasRequiredPromise) return promise;
	hasRequiredPromise = 1;
	var Ajv = requireAjv();
	var HARError = requireError();
	var schemas = requireLib();

	var ajv;

	function validate (name, data) {
	  data = data || {};

	  // validator config
	  ajv = ajv || new Ajv({
	    allErrors: true,
	    schemas: schemas
	  });

	  var validate = ajv.getSchema(name + '.json');

	  return new Promise(function (resolve, reject) {
	    var valid = validate(data);

	    !valid ? reject(new HARError(validate.errors)) : resolve(data);
	  })
	}

	promise.afterRequest = function (data) {
	  return validate('afterRequest', data)
	};

	promise.beforeRequest = function (data) {
	  return validate('beforeRequest', data)
	};

	promise.browser = function (data) {
	  return validate('browser', data)
	};

	promise.cache = function (data) {
	  return validate('cache', data)
	};

	promise.content = function (data) {
	  return validate('content', data)
	};

	promise.cookie = function (data) {
	  return validate('cookie', data)
	};

	promise.creator = function (data) {
	  return validate('creator', data)
	};

	promise.entry = function (data) {
	  return validate('entry', data)
	};

	promise.har = function (data) {
	  return validate('har', data)
	};

	promise.header = function (data) {
	  return validate('header', data)
	};

	promise.log = function (data) {
	  return validate('log', data)
	};

	promise.page = function (data) {
	  return validate('page', data)
	};

	promise.pageTimings = function (data) {
	  return validate('pageTimings', data)
	};

	promise.postData = function (data) {
	  return validate('postData', data)
	};

	promise.query = function (data) {
	  return validate('query', data)
	};

	promise.request = function (data) {
	  return validate('request', data)
	};

	promise.response = function (data) {
	  return validate('response', data)
	};

	promise.timings = function (data) {
	  return validate('timings', data)
	};
	return promise;
}

export { requirePromise as __require };
