import { clearDirectory } from '../../util/clearDirectory.mjs';
import { createFile } from '../../util/createFile.mjs';
import { debugFunction } from '../../util/debugFunction.mjs';
import { isFileOrFolderExists } from '../../util/isFileOrFolderExists.mjs';
import { parseJSON } from '../../util/parseJSON.mjs';
import { readFile } from '../../util/readFile.mjs';

const cleanUpTemplate = async (config) => {
    debugFunction(config.isDebug, { config }, '[PrepareTemplate] cleanUpTemplate');
    let repositoryMapFileConfig = null;
    if (await isFileOrFolderExists(config.templateCatalogPath)) {
        if (await isFileOrFolderExists(config.repositoryMapFilePath)) {
            repositoryMapFileConfig = await readFile(config.repositoryMapFilePath).then(async (bufferData) => parseJSON(bufferData.toString()));
        }
        await clearDirectory(config.templateCatalogPath);
        const newContent = repositoryMapFileConfig;
        if (newContent !== null) {
            newContent.fileMap = [];
            newContent.templateFileList = [];
            newContent.rootPathFileList = [];
            await createFile({
                filePath: config.repositoryMapFilePath,
                content: JSON.stringify(newContent),
                isDebug: config.isDebug,
                options: {
                    overwriteFile: true,
                },
            });
        }
    }
    debugFunction(config.isDebug, { config }, '[PrepareTemplate] end cleanUpTemplate');
    return config;
};

export { cleanUpTemplate };
