#!/usr/bin/env node
import minimist from '../node_modules/minimist/index.mjs';
import { defaultRepositoryMapFileConfig } from './feature/config/const.mjs';
import { getTemplateConfig } from './feature/config/defaultTemplateConfig.mjs';
import { bumpVersion } from './feature/prepareTemplate/bumpVersion.mjs';
import { cleanUpTemplate } from './feature/prepareTemplate/cleanUpTemplate.mjs';
import { prepareFileList } from './feature/prepareTemplate/prepareFileList.mjs';
import { scanProjectFolder } from './feature/prepareTemplate/scanProjectFolder.mjs';
import { updateTemplateConfig } from './feature/prepareTemplate/updateTemplateConfig.mjs';
import { createCatalog } from './util/createCatalog.mjs';
import { createFile } from './util/createFile.mjs';
import { debugFunction } from './util/debugFunction.mjs';
import { formatJsonWithPrettier } from './util/formatPrettier.mjs';
import { isFileOrFolderExists } from './util/isFileOrFolderExists.mjs';

const prepareTemplate = async (args) => {
    const config = await getTemplateConfig(args);
    debugFunction(config.isDebug, '=== Start prepare template ===', '[PrepareTemplate]');
    if (!(await isFileOrFolderExists(config.templateCatalogPath)) || process.env.SDEBUG !== 'true') {
        await createCatalog(config.templateCatalogPath);
    }
    if (((await isFileOrFolderExists(config.templateCatalogPath)) &&
        !(await isFileOrFolderExists(config.repositoryMapFilePath))) ||
        process.env.SDEBUG !== 'true') {
        debugFunction(config.isDebug, `isFileOrFolderExists ${config.repositoryMapFilePath}`, '[PrepareTemplate]');
        debugFunction(config.isDebug, config, '[PrepareTemplate]');
        await createFile({
            filePath: config.repositoryMapFilePath,
            content: JSON.stringify(defaultRepositoryMapFileConfig),
            isDebug: config.isDebug,
            options: {
                overwriteFile: true,
            },
        });
        config.bumpVersion = false;
    }
    debugFunction(config.isDebug, config, '[PrepareTemplate] END init');
    return config;
};
const args = minimist(process.argv.slice(2));
let finalConfig = {
    isDebug: false,
};
prepareTemplate(args)
    .then((config) => {
    finalConfig = config;
    return bumpVersion(config);
})
    .then((config) => {
    finalConfig = config;
    return cleanUpTemplate(config);
})
    .then((config) => {
    finalConfig = config;
    return scanProjectFolder(config);
})
    .then(({ config, templateFileList }) => {
    finalConfig = config;
    return prepareFileList({ config, templateFileList });
})
    .then(({ config, templateFileList, fileList, rootPathFileList }) => {
    finalConfig = config;
    return updateTemplateConfig({ config, fileList, templateFileList, rootPathFileList });
})
    .then(async ({ config }) => {
    await formatJsonWithPrettier(config.repositoryMapFilePath);
})
    .finally(() => {
    debugFunction(finalConfig?.isDebug, { finalConfig }, '[PrepareTemplate] final config');
    debugFunction(finalConfig?.isDebug, '=== Final prepare template ===', '[PrepareTemplate]');
});

export { prepareTemplate };
