import { createCatalog } from './createCatalog.mjs';
import { createFile } from './createFile.mjs';
import { debugFunction } from './debugFunction.mjs';
import { isFileOrFolderExists } from './isFileOrFolderExists.mjs';
import { objectToBuffer } from './objectToBuffer.mjs';
import { parseJSON } from './parseJSON.mjs';
import { readFile } from './readFile.mjs';
import { wgetAsync } from './wget.mjs';

async function downloadConfig(config) {
    debugFunction(config.isDebug, '=== SNP INIT ===', '[INIT] downloadConfig');
    const snpFileMapConfig = await readFile(config.snpFileMapConfig).then(async (bufferData) => parseJSON(bufferData.toString()));
    try {
        debugFunction(config.isDebug, {
            remoteRootRepositoryUrl: config.remoteRootRepositoryUrl,
            remoteRepository: config.remoteRepository,
            fileName: config.REPOSITORY_MAP_FILE_NAME,
            remoteFileMapURL: config.remoteFileMapURL,
        }, '[INIT - downloadConfig]');
        if (!(await isFileOrFolderExists(config.temporaryFolder))) {
            await createCatalog(config.temporaryFolder);
        }
        // TODO config.temporaryFolder is nesesery
        return await wgetAsync(config.remoteFileMapURL, config.temporaryFolder)
            .then(async (snpFileMapConfigContent) => {
            let currentConfig = {};
            const downloadContent = parseJSON(snpFileMapConfigContent);
            currentConfig = {
                ...snpFileMapConfig,
                ...downloadContent,
            };
            const combinedConfig = currentConfig;
            if (!combinedConfig.createdFileMap) {
                combinedConfig.createdFileMap = [];
            }
            if (!combinedConfig.snpFileMap) {
                combinedConfig.snpFileMap = {};
            }
            await createFile({
                filePath: config.snpFileMapConfig,
                content: objectToBuffer(combinedConfig),
                options: {
                    overwriteFile: true,
                },
            });
            return combinedConfig;
        })
            .then((combinedConfig) => {
            debugFunction(config.isDebug, { ...config, templateVersion: combinedConfig.templateVersion }, '[INIT] downloadConfig - end');
            return { ...config, templateVersion: combinedConfig.templateVersion };
        });
    }
    catch (err) {
        console.error('Error while downloading config from github', err);
        throw err;
    }
}

export { downloadConfig };
