import path__default from 'path';

/**
 * Filtruje tablicę ścieżek plików na podstawie podanych opcji.
 *
 * @param files - Tablica ścieżek do plików.
 * @param options - Opcjonalne parametry filtrowania.
 * @returns Tablica ścieżek do przefiltrowanych plików.
 */
function filterFiles(files, options = {}) {
    const { includeExtensions = [], excludeExtensions = [], ignorePaths = [] } = options;
    return files.filter((filePath) => {
        const fileExt = path__default.extname(filePath).toLowerCase();
        const fileDir = path__default.dirname(filePath);
        if (ignorePaths.some((ignorePath) => fileDir.startsWith(ignorePath))) {
            return false;
        }
        if (includeExtensions.length > 0 && !includeExtensions.includes(fileExt)) {
            return false;
        }
        if (excludeExtensions.includes(fileExt)) {
            return false;
        }
        return true;
    });
}

export { filterFiles };
