import fs from 'fs';
import { isFileOrFolderExists } from './isFileOrFolderExists.mjs';

async function toCreateFile({ filePath, content, options = { overwriteFile: true, backupFile: true }, }) {
    const { overwriteFile, backupFile } = options;
    try {
        const fileExists = await isFileOrFolderExists(filePath);
        if (backupFile && fileExists) {
            const existingContent = await fs.promises.readFile(filePath, 'utf-8');
            if (existingContent !== content.toString()) {
                const backupFilePath = filePath + '.backup';
                await fs.promises.copyFile(filePath, backupFilePath);
            }
        }
        if (((await isFileOrFolderExists(filePath)) && overwriteFile) || !(await isFileOrFolderExists(filePath))) {
            // If overwriteFile is true or backupFile is false, overwrite the file or create a new one
            await fs.promises.writeFile(filePath, content);
        }
    }
    catch (error) {
        throw error; // You might want to handle the error differently based on your application's needs
    }
}

export { toCreateFile };
